==> owncloud-8.2.2p3.tgz: owncloud/settings/l10n/ia.js <==
OC.L10N.register(
    "settings",
    {
    "Log" : "Registro",
    "Language changed" : "Linguage cambiate",
    "Invalid request" : "Requesta invalide",
    "Wrong password" : "Contrasigno errate",
    "Saved" : "Salveguardate",
    "Email sent" : "Message de e-posta inviate",
    "All" : "Omne",
    "Very weak password" : "Contrasigno multo debile",
    "Weak password" : "Contrasigno debile",
    "So-so password" : "Contrasigno passabile",
    "Good password" : "Contrasigno bon",
    "Strong password" : "Contrasigno forte",
    "Delete" : "Deler",
    "Groups" : "Gruppos",
    "never" : "nunquam",
    "__language_name__" : "Interlingua",
    "More" : "Plus",
    "by" : "per",
    "Cheers!" : "Acclamationes!",
    "Get the apps to sync your files" : "Obtene le apps (applicationes) pro synchronizar tu files",
    "Password" : "Contrasigno",
    "Unable to change your password" : "Non pote cambiar tu contrasigno",
    "Current password" : "Contrasigno currente",
    "New password" : "Nove contrasigno",
    "Change password" : "Cambiar contrasigno",
    "Email" : "E-posta",
    "Your email address" : "Tu adresse de e-posta",
    "Profile picture" : "Imagine de profilo",
    "Cancel" : "Cancellar",
    "Language" : "Linguage",
    "Help translate" : "Adjuta a traducer",
    "Username" : "Nomine de usator",
    "Create" : "Crear",
    "Group" : "Gruppo",
    "Default Quota" : "Quota predeterminate",
    "Other" : "Altere",
    "Quota" : "Quota"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/settings/l10n/ia.js <==
OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Contrasigno errate",
    "Couldn't send reset email. Please contact your administrator." : "Non poteva inviar le message de reinitialisation. Per favor contacta tu administrator.",
    "Saved" : "Salveguardate",
    "Email sent" : "Message de e-posta inviate",
    "__language_name__" : "Interlingua",
    "Language changed" : "Linguage cambiate",
    "Invalid request" : "Requesta invalide",
    "All" : "Omne",
    "Delete" : "Deler",
    "Very weak password" : "Contrasigno multo debile",
    "Weak password" : "Contrasigno debile",
    "So-so password" : "Contrasigno passabile",
    "Good password" : "Contrasigno bon",
    "Strong password" : "Contrasigno forte",
    "Groups" : "Gruppos",
    "never" : "nunquam",
    "Cheers!" : "Acclamationes!",
    "days" : "dies",
    "Log" : "Registro",
    "None" : "Necun",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Particularmente quando usar le cliente scriptorio pro synchronisar files, le uso de SQLite es discoragiate.",
    "Get the apps to sync your files" : "Obtene le apps (applicationes) pro synchronizar tu files",
    "Profile picture" : "Imagine de profilo",
    "Cancel" : "Cancellar",
    "Email" : "E-posta",
    "Your email address" : "Tu adresse de e-posta",
    "Password" : "Contrasigno",
    "Unable to change your password" : "Non pote cambiar tu contrasigno",
    "Current password" : "Contrasigno currente",
    "New password" : "Nove contrasigno",
    "Change password" : "Cambiar contrasigno",
    "Language" : "Linguage",
    "Help translate" : "Adjuta a traducer",
    "Name" : "Nomine",
    "Username" : "Nomine de usator",
    "Personal" : "Personal",
    "Admin" : "Administration",
    "Error" : "Error",
    "E-Mail" : "E-posta",
    "Create" : "Crear",
    "Group" : "Gruppo",
    "Default Quota" : "Quota predeterminate",
    "Other" : "Altere",
    "Quota" : "Quota"
},
"nplurals=2; plural=(n != 1);");
